pub struct Mask(Arc<MaskRepr>);Expand description
A mask.
Tuple Fields
0: Arc<MaskRepr>Implementations
Sourceimpl Mask
impl Mask
Sourcepub fn new_luminance(pixmap: &Pixmap) -> Self
pub fn new_luminance(pixmap: &Pixmap) -> Self
Create a new luminance mask from the pixmap.
Sourcepub fn from_parts(data: Vec<u8>, width: u16, height: u16) -> Self
pub fn from_parts(data: Vec<u8>, width: u16, height: u16) -> Self
Create a new mask from the given alpha data.
The data vector must be of length width * height exactly.
The pixels are in row-major order.
Panics
Panics if the data vector is not of length width * height.
fn new_with(pixmap: &Pixmap, alpha_mask: bool) -> Self